import DatasourceAuthManager from "./DatasourceAuthManager";
import TextDatasource from "./TextDatasource";
import Credentials from "../credentials/Credentials";
/**
 * Datasource for Google Drive archives
 * @augments TextDatasource
 * @memberof module:Buttercup
 */
export default class GoogleDriveDatasource extends TextDatasource {
    authManager: DatasourceAuthManager;
    client: any;
    fileID: string;
    token: string;
    refreshToken: string;
    oldRefreshToken: string;
    newRefreshToken: string;
    /**
     * Datasource for Google Drive connections
     * @param {Credentials} credentials The credentials instance with which to
     *  configure the datasource with
     */
    constructor(credentials: Credentials);
    /**
     * Load an archive from the datasource
     * @param {Credentials} credentials The credentials for decryption
     * @returns {Promise.<LoadedVaultData>} A promise that resolves archive history
     * @memberof GoogleDriveDatasource
     */
    loadToGoogleDrive(id: any): Promise<any>;
    load(credentials: any, isUnlock?: boolean, hasAuthed?: boolean): any;
    saveToGoogleDrive(id: any, contents: any, name?: any): Promise<string>;
    getPutFileOptions(token: any, { parentID, id, contents, name }?: {
        parentID?: any;
        id?: any;
        contents?: string;
        name?: string;
    }): {
        url: string;
        options: {
            method: string;
            params: {
                uploadType: string;
            };
            headers: {
                Authorization: string;
                "Content-Type": string;
                "Content-Length": string;
            };
            body: ArrayBufferLike;
        };
    };
    /**
     * Save an archive using the datasource
     * @param {Array.<String>} history The archive history to save
     * @param {Credentials} credentials The credentials to save with
     * @returns {Promise} A promise that resolves when saving has completed
     * @memberof GoogleDriveDatasource
     */
    save(history: any, credentials: any, hasAuthed?: boolean): any;
    /**
     * Whether or not the datasource supports bypassing remote fetch operations
     * @returns {Boolean} True if content can be set to bypass fetch operations,
     *  false otherwise
     * @memberof GoogleDriveDatasource
     */
    supportsRemoteBypass(): boolean;
    /**
     * Update the OAuth2 tokens
     * @param {String} accessToken The access token
     * @param {String=} refreshToken The refresh token
     * @memberof GoogleDriveDatasource
     */
    updateTokens(accessToken: any, refreshToken: any): void;
}
