import TextDatasource from "./TextDatasource";
import Credentials from "../credentials/Credentials";
import { DatasourceLoadedData, EncryptedContent, History } from "../types";
/**
 * WebDAV datasource for reading and writing remote archives
 * @augments TextDatasource
 * @memberof module:Buttercup
 */
export default class WebDAVDatasource extends TextDatasource {
    _client: any;
    _path: string;
    /**
     * Constructor for the datasource
     * @param credentials Credentials for the datasource
     */
    constructor(credentials: Credentials);
    /**
     * The WebDAV client instance
     * @memberof WebDAVDatasource
     */
    get client(): any;
    /**
     * The remote archive path
     * @memberof WebDAVDatasource
     */
    get path(): string;
    /**
     * Load archive history from the datasource
     * @param credentials The credentials for archive decryption
     * @returns A promise resolving archive history
     * @memberof WebDAVDatasource
     */
    load(credentials: Credentials): Promise<DatasourceLoadedData>;
    /**
     * Save archive contents to the WebDAV service
     * @param history Archive history
     * @param credentials The credentials for encryption
     * @returns A promise resolving when the save is complete
     * @memberof WebDAVDatasource
     */
    save(history: History, credentials: Credentials): Promise<EncryptedContent>;
    /**
     * Whether or not the datasource supports bypassing remote fetch operations
     * @returns True if content can be set to bypass fetch operations,
     *  false otherwise
     * @memberof WebDAVDatasource
     */
    supportsRemoteBypass(): boolean;
}
