import StorageInterface from "../storage/StorageInterface";
import Vault from "../core/Vault";
import { EntryID, VaultID } from "../types";
interface DomainScores {
    [domain: string]: number;
}
interface ProcessedSearchEntry {
    id: EntryID;
    type: string;
    properties: {
        [property: string]: string;
    };
    urls: Array<string>;
    vaultID: VaultID;
    domainScores: DomainScores;
}
export interface SearcherFactory {
    (items: Array<any>): any;
}
export interface SearchResult {
    id: EntryID;
    type: string;
    properties: {
        [property: string]: string;
    };
    urls: Array<string>;
    vaultID: VaultID;
}
interface SearchScores {
    [vaultID: string]: {
        [entryID: string]: DomainScores;
    };
}
/**
 * Search class for searching entries
 * @memberof module:Buttercup
 */
export default class Search {
    _entries: Array<ProcessedSearchEntry>;
    _fuse: any;
    _memory: StorageInterface;
    _results: Array<SearchResult>;
    _searcherFactory: SearcherFactory;
    _scores: SearchScores;
    _vaults: Array<Vault>;
    constructor(vaults: Array<Vault>, memory?: StorageInterface, searcherFactory?: SearcherFactory);
    /**
     * Last search results
     */
    get results(): Array<SearchResult>;
    /**
     * Increment the score of a URL in an entry
     * @param vaultID The vault ID
     * @param entryID The entry ID
     * @param url The URL to increment for
     */
    incrementScore(vaultID: VaultID, entryID: EntryID, url: string): Promise<void>;
    /**
     * Prepare the search instance by processing
     * entries
     */
    prepare(): Promise<void>;
    /**
     * Search for entries by term
     * @param term The term to search for
     * @returns An array of search results
     */
    searchByTerm(term: string, fromPopup: boolean): Array<SearchResult>;
    /**
     * Search for entries by URL
     * @param url The URL to search with
     * @returns An array of search results
     */
    searchByURL(url: string): Array<SearchResult>;
}
export {};
